@@ -16,6 +16,7 @@
 // along with GNU uCommon C++.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <config.h>
+#include <ucommon/export.h>
 #include <ucommon/thread.h>
 #include <ucommon/fsys.h>
 #include <ucommon/string.h>
@@ -42,6 +43,12 @@
 #include <errno.h>
 #include <string.h>
 
+#ifdef  HAVE_POSIX_FADVISE
+#ifndef POSIX_FADV_RANDOM
+#undef  HAVE_POSIX_FADVISE
+#endif
+#endif
+
 #ifdef  HAVE_DIRENT_H
 #include <dirent.h>
 #endif
