@@ -16,6 +16,7 @@
 // along with GNU uCommon C++.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <config.h>
+#include <ucommon/export.h>
 #include <ucommon/object.h>
 #include <ucommon/thread.h>
 #include <ucommon/timers.h>
@@ -1932,7 +1933,7 @@ void Thread::setPriority(void)
 }
 
 #else
-void Thread::setPriority(void) {};
+void Thread::setPriority(void) {}
 #endif
 
 void Thread::concurrency(int level)
